@@ -89,20 +89,6 @@ class SessionTest(TmuxTestCase):
         )
 
 
-class SessionCleanTest(TmuxTestCase):
-
-    def test_is_session_clean(self):
-        '''Session.is_clean() returns False for sessions with previous commands'''
-
-        self.assertEqual(self.session.is_clean(), True)
-        self.session.attached_window().attached_pane().send_keys('top')
-        sleep(.4)
-        self.session.attached_window().list_panes()
-        self.session.attached_window().attached_pane().send_keys(
-            'C-c', enter=False)
-        self.assertEqual(self.session.is_clean(), False)
-
-
 class SessionNewTest(TmuxTestCase):
 
     def test_new_session(self):
