@@ -26,14 +26,12 @@ class TwoPaneTest(TmuxTestCase):
       panes:
       - shell_command:
         - vim
-        start_directory: '~'
       - shell_command:
         - echo "hey"
       window_name: editor
     - panes:
       - shell_command:
         - tail -F /var/log/syslog
-        start_directory: /var/log
       window_name: logging
     - window_name: test
       panes:
@@ -72,7 +70,6 @@ class ThreePaneTest(TmuxTestCase):
       panes:
       - shell_command:
         - vim
-        start_directory: '~'
       - shell_command:
         - echo "hey"
       - shell_command:
@@ -114,7 +111,6 @@ class FocusAndPaneIndexTest(TmuxTestCase):
       panes:
       - shell_command:
         - vim
-        start_directory: '~'
       - shell_command:
         - echo "hey"
       - shell_command:
@@ -125,8 +121,7 @@ class FocusAndPaneIndexTest(TmuxTestCase):
       panes:
       - shell_command:
         - vim
-        start_directory: '~'
-        focus: true
+        rocus: true
       - shell_command:
         - echo "hey"
       - shell_command:
@@ -273,5 +268,56 @@ class WindowAutomaticRename(TmuxTestCase):
         self.assertNotEqual(w.get('window_name'), 'man')
 
 
+class StartDirectoryTest(TmuxTestCase):
+    yaml_config = '''
+    session_name: sampleconfig
+    start_directory: '/var'
+    windows:
+    - window_name: test
+      start_directory: '/var/log'
+      layout: main-horizontal
+      options:
+          main-pane-height: 50
+      panes:
+      - shell_command:
+        - echo "hey"
+      - shell_command:
+        - echo "moo"
+    - window_name: testsa
+      start_directory: '/dev'
+      layout: main-horizontal
+      panes:
+      - shell_command:
+        - pwd
+      - shell_command:
+        - echo "hey"
+      - shell_command:
+        - echo "moo"
+    - window_name: testsa3
+      layout: main-horizontal
+      panes:
+      - shell_command:
+        - pwd
+      - shell_command:
+        - echo "hey"
+      - shell_command:
+        - echo "moo3"
+    '''
+
+    def test_start_directory(self):
+
+        sconfig = kaptan.Kaptan(handler='yaml')
+        sconfig = sconfig.import_config(self.yaml_config).get()
+        sconfig = config.expand(sconfig)
+        sconfig = config.trickle(sconfig)
+
+        builder = WorkspaceBuilder(sconf=sconfig)
+        builder.build(session=self.session)
+
+        assert(self.session == builder.session)
+        for window in self.session.windows:
+            for p in window.panes:
+                self.assertTrue(any(p.get('pane_start_path', ['/var/log', '/dev/', '/var/'])))
+
 if __name__ == '__main__':
     unittest.main()
